@@ -5,10 +5,9 @@ storage of a primitive, and is the constraint for the storage type of a
 `BitVec`.
 !*/
 
-use std::{
+use core::{
 	cmp::Eq,
 	convert::From,
-	default::Default,
 	fmt::{
 		Binary,
 		Debug,
@@ -16,6 +15,7 @@ use std::{
 		LowerHex,
 		UpperHex,
 	},
+	mem::size_of,
 	ops::{
 		Not,
 		BitAnd,
@@ -45,9 +45,6 @@ pub trait Bits:
 	//  Permit indexing into a generic array
 	+ Copy
 	+ Debug
-	//  `BitVec` cannot push new elements without this. (Well, it CAN, but
-	//  `mem::uninitialized` is Considered Harmful.)
-	+ Default
 	+ Display
 	//  Permit testing a value against 1 in `get()`.
 	+ Eq
@@ -66,21 +63,21 @@ pub trait Bits:
 	+ UpperHex
 {
 	/// The width in bits of this type.
-	const WIDTH: u8 = 1 << Self::BITS; // size_of::<Self>();
+	const WIDTH: u8 = size_of::<Self>() as u8 * 8;
 
 	/// The number of bits required to *index* the type. This is always
 	/// log<sub>2</sub> of the type width.
 	///
-	/// Incidentally, this can be computed as `size_of().trailing_zeroes()` once
+	/// Incidentally, this can be computed as `size_of().trailing_zeros()` once
 	/// that becomes a valid constexpr.
-	const BITS: u8; // = size_of::<Self>().trailing_zeroes();
+	const BITS: u8; // = size_of::<Self>().trailing_zeros() as u8;
 
 	/// The bitmask to turn an arbitrary usize into the bit index. Bit indices
 	/// are always stored in the lowest bits of an index value.
 	const MASK: u8 = Self::WIDTH - 1;
 
 	/// The maximum number of this type that can be held in a `BitVec`.
-	const MAX_ELT: usize = ::std::usize::MAX >> Self::BITS;
+	const MAX_ELT: usize = core::usize::MAX >> Self::BITS;
 
 	/// Set a specific bit in an element to a given value.
 	fn set(&mut self, place: u8, value: bool) {
@@ -99,10 +96,12 @@ pub trait Bits:
 	}
 
 	/// Counts how many bits are set.
-	fn ones(&self) -> u32;
+	#[inline(always)]
+	fn ones(&self) -> usize;
 
 	/// Counts how many bits are unset.
-	fn zeros(&self) -> u32;
+	#[inline(always)]
+	fn zeros(&self) -> usize;
 
 	/// Splits a `usize` cursor into an (element, bit) tuple.
 	///
@@ -114,7 +113,7 @@ pub trait Bits:
 	/// Joins a `usize` element cursor and `u8` bit cursor into a single
 	/// `usize` cursor.
 	fn join(elt: usize, bit: u8) -> usize {
-		assert!(elt <= ::std::usize::MAX >> Self::BITS, "Element count out of range!");
+		assert!(elt <= core::usize::MAX >> Self::BITS, "Element count out of range!");
 		assert!(bit <= Self::MASK, "Bit count out of range!");
 		(elt << Self::BITS) | bit as usize
 	}
@@ -129,12 +128,14 @@ pub trait Bits:
 impl Bits for u8 {
 	const BITS: u8 = 3;
 
-	fn ones(&self) -> u32 {
-		self.count_ones()
+	#[inline(always)]
+	fn ones(&self) -> usize {
+		self.count_ones() as usize
 	}
 
-	fn zeros(&self) -> u32 {
-		self.count_zeros()
+	#[inline(always)]
+	fn zeros(&self) -> usize {
+		self.count_zeros() as usize
 	}
 
 	const TY: &'static str = "u8";
@@ -143,12 +144,14 @@ impl Bits for u8 {
 impl Bits for u16 {
 	const BITS: u8 = 4;
 
-	fn ones(&self) -> u32 {
-		self.count_ones()
+	#[inline(always)]
+	fn ones(&self) -> usize {
+		self.count_ones() as usize
 	}
 
-	fn zeros(&self) -> u32 {
-		self.count_zeros()
+	#[inline(always)]
+	fn zeros(&self) -> usize {
+		self.count_zeros() as usize
 	}
 
 	const TY: &'static str = "u16";
@@ -157,12 +160,14 @@ impl Bits for u16 {
 impl Bits for u32 {
 	const BITS: u8 = 5;
 
-	fn ones(&self) -> u32 {
-		self.count_ones()
+	#[inline(always)]
+	fn ones(&self) -> usize {
+		self.count_ones() as usize
 	}
 
-	fn zeros(&self) -> u32 {
-		self.count_zeros()
+	#[inline(always)]
+	fn zeros(&self) -> usize {
+		self.count_zeros() as usize
 	}
 
 	const TY: &'static str = "u32";
@@ -173,12 +178,14 @@ impl Bits for u32 {
 impl Bits for u64 {
 	const BITS: u8 = 6;
 
-	fn ones(&self) -> u32 {
-		self.count_ones()
+	#[inline(always)]
+	fn ones(&self) -> usize {
+		self.count_ones() as usize
 	}
 
-	fn zeros(&self) -> u32 {
-		self.count_zeros()
+	#[inline(always)]
+	fn zeros(&self) -> usize {
+		self.count_zeros() as usize
 	}
 
 	const TY: &'static str = "u64";
