@@ -33,26 +33,34 @@ iteration in both directions, bit shifts, and, of course, access to the
 underlying storage as a slice.
 !*/
 
+#![cfg_attr(not(feature = "std"), no_std)]
+#![cfg_attr(all(feature = "alloc", not(feature = "std")), feature(alloc))]
+
+#[cfg(all(feature = "alloc", not(feature = "std")))]
+extern crate alloc;
+
+#[cfg(feature = "std")]
+extern crate core;
+
 #[macro_use]
 mod macros;
 
 mod bits;
-mod endian;
+mod cursor;
 mod slice;
-mod vec;
 
-pub use {
+pub use crate::{
 	bits::Bits,
-	endian::*,
-	macros::*,
+	cursor::{
+		Cursor,
+		BigEndian,
+		LittleEndian,
+	},
 	slice::BitSlice,
-	vec::BitVec,
 };
 
-//  The `Index` trait returns references to bools, and it is impossible to make
-//  an address for a bit in the middle of a byte. Therefore, `Index::index`
-//  references these static values depending on the value of the bit.
-//
-//  This is *such* a hack, but, That’s Rust For Ya.
-static TRUE: bool = true;
-static FALSE: bool = false;
+#[cfg(feature = "alloc")]
+mod vec;
+
+#[cfg(feature = "alloc")]
+pub use crate::vec::BitVec;
